@@ -20,13 +20,6 @@ from octue.runner import Runner
 from twined import Twine
 
 
-# Import the Dataflow deployer only if the `apache-beam` package is available (due to installing `octue` with the
-# `dataflow` extras option).
-APACHE_BEAM_PACKAGE_AVAILABLE = bool(importlib.util.find_spec("apache_beam"))
-
-if APACHE_BEAM_PACKAGE_AVAILABLE:
-    from octue.cloud.deployment.google.dataflow.deployer import DataflowDeployer
-
 logger = logging.getLogger(__name__)
 
 global_cli_context = {}
@@ -40,13 +33,6 @@ global_cli_context = {}
     show_default=True,
     help="UUID of the analysis being undertaken. None (for local use) will cause a unique ID to be generated.",
 )
-@click.option(
-    "--skip-checks/--no-skip-checks",
-    default=False,
-    is_flag=True,
-    show_default=True,
-    help="Skips the input checking. This can be a timesaver if you already checked data directories (especially if manifests are large).",
-)
 @click.option("--logger-uri", default=None, show_default=True, help="Stream logs to a websocket at the given URI.")
 @click.option(
     "--log-level",
@@ -63,7 +49,7 @@ global_cli_context = {}
     help="Forces a reset of analysis cache and outputs [For future use, currently not implemented]",
 )
 @click.version_option(version=pkg_resources.get_distribution("octue").version)
-def octue_cli(id, skip_checks, logger_uri, log_level, force_reset):
+def octue_cli(id, logger_uri, log_level, force_reset):
     """Octue CLI, enabling a data service / digital twin to be run like a command line application.
 
     When acting in CLI mode, results are read from and written to disk (see
@@ -71,7 +57,6 @@ def octue_cli(id, skip_checks, logger_uri, log_level, force_reset):
     Once your application has run, you'll be able to find output values and manifest in your specified --output-dir.
     """
     global_cli_context["analysis_id"] = id
-    global_cli_context["skip_checks"] = skip_checks
     global_cli_context["logger_uri"] = logger_uri
     global_cli_context["log_handler"] = None
     global_cli_context["log_level"] = log_level.upper()
@@ -143,7 +128,6 @@ def run(app_dir, data_dir, config_dir, input_dir, twine):
         configuration_values=configuration_values,
         configuration_manifest=configuration_manifest,
         children=children,
-        skip_checks=global_cli_context["skip_checks"],
     )
 
     analysis = runner.run(
@@ -172,13 +156,14 @@ def run(app_dir, data_dir, config_dir, input_dir, twine):
 )
 @click.option("--timeout", type=click.INT, default=None, show_default=True, help="Timeout in seconds for serving.")
 @click.option(
+    "--rm",
     "--delete-topic-and-subscription-on-exit",
     is_flag=True,
     default=False,
     show_default=True,
-    help="Delete Google Pub/Sub topics and subscriptions on exit.",
+    help="Delete the Google Pub/Sub topic and subscription for the service on exit.",
 )
-def start(service_configuration_path, service_id, timeout, delete_topic_and_subscription_on_exit):
+def start(service_configuration_path, service_id, timeout, rm):
     """Start the service as a child to be asked questions by other services."""
     service_configuration, app_configuration = load_service_and_app_configuration(service_configuration_path)
 
@@ -188,7 +173,7 @@ def start(service_configuration_path, service_id, timeout, delete_topic_and_subs
         configuration_values=app_configuration.configuration_values,
         configuration_manifest=app_configuration.configuration_manifest,
         children=app_configuration.children,
-        skip_checks=global_cli_context["skip_checks"],
+        output_location=app_configuration.output_location,
     )
 
     run_function = functools.partial(
@@ -214,7 +199,7 @@ def start(service_configuration_path, service_id, timeout, delete_topic_and_subs
         run_function=run_function,
     )
 
-    service.serve(timeout=timeout, delete_topic_and_subscription_on_exit=delete_topic_and_subscription_on_exit)
+    service.serve(timeout=timeout, delete_topic_and_subscription_on_exit=rm)
 
 
 @octue_cli.group()
@@ -270,7 +255,11 @@ def cloud_run(octue_configuration_path, service_id, update, no_cache):
 @click.option("--image-uri", type=str, default=None, help="The actual image URI to use when creating the Dataflow job.")
 def dataflow(octue_configuration_path, service_id, no_cache, update, dataflow_job_only, image_uri):
     """Deploy an app as a Google Dataflow streaming job."""
-    if not APACHE_BEAM_PACKAGE_AVAILABLE:
+    if bool(importlib.util.find_spec("apache_beam")):
+        # Import the Dataflow deployer only if the `apache-beam` package is available (due to installing `octue` with
+        # the `dataflow` extras option).
+        from octue.cloud.deployment.google.dataflow.deployer import DataflowDeployer
+    else:
         raise ImportWarning(
             "To use this CLI command, you must install `octue` with the `dataflow` option e.g. "
             "`pip install octue[dataflow]`"
